==> igniteui-react-core-18.0.0.tgz: package/esm5/lib/WebAccordionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebAccordionDescription } from "./WebAccordionDescription";
/**
 * @hidden
 */
var WebAccordionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebAccordionDescriptionMetadata, _super);
    function WebAccordionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebAccordionDescriptionMetadata.b = function (a) {
        if (WebAccordionDescriptionMetadata.a == null) {
            WebAccordionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebAccordionDescriptionMetadata.c(WebAccordionDescriptionMetadata.a);
        }
        if (a.g(WebAccordionDescriptionMetadata.a)) {
            return;
        }
        a.s(WebAccordionDescriptionMetadata.a);
    };
    WebAccordionDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Accordion");
        a.item("SingleExpand", "Boolean");
    };
    WebAccordionDescriptionMetadata.d = function (a) {
        WebAccordionDescriptionMetadata.b(a);
        a.u("WebAccordion", function () { return new WebAccordionDescription(); });
        a.t("WebAccordion", WebAccordionDescriptionMetadata.a);
    };
    WebAccordionDescriptionMetadata.$t = markType(WebAccordionDescriptionMetadata, 'WebAccordionDescriptionMetadata');
    WebAccordionDescriptionMetadata.a = null;
    return WebAccordionDescriptionMetadata;
}(Base));
export { WebAccordionDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebAccordionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebAccordionDescription } from "./WebAccordionDescription";
/**
 * @hidden
 */
var WebAccordionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebAccordionDescriptionMetadata, _super);
    function WebAccordionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebAccordionDescriptionMetadata.b = function (a) {
        if (WebAccordionDescriptionMetadata.a == null) {
            WebAccordionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebAccordionDescriptionMetadata.c(WebAccordionDescriptionMetadata.a);
        }
        if (a.j(WebAccordionDescriptionMetadata.a)) {
            return;
        }
        a.y(WebAccordionDescriptionMetadata.a);
    };
    WebAccordionDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Accordion");
        a.item("__tagNameWC", "String:igc-accordion");
        a.item("SingleExpand", "Boolean");
    };
    WebAccordionDescriptionMetadata.d = function (a) {
        WebAccordionDescriptionMetadata.b(a);
        a.aa("WebAccordion", function () { return new WebAccordionDescription(); });
        a.z("WebAccordion", WebAccordionDescriptionMetadata.a);
    };
    WebAccordionDescriptionMetadata.$t = markType(WebAccordionDescriptionMetadata, 'WebAccordionDescriptionMetadata');
    WebAccordionDescriptionMetadata.a = null;
    return WebAccordionDescriptionMetadata;
}(Base));
export { WebAccordionDescriptionMetadata };
